#
# spec file for package purpose
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Used by optional plugins
%global __requires_exclude qmlimport\\((Ubuntu\\.OnlineAccounts|org\\.kde\\.kdeconnect).*

%define lname   libKF5Purpose5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           purpose
Version:        5.115.0
Release:        1.1
Summary:        Framework to integrate services and actions in applications
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  intltool
BuildRequires:  libaccounts-glib-devel
BuildRequires:  libsignon-qt5-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(AccountsQt5)
BuildRequires:  cmake(KAccounts)
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Kirigami2) >= %{_kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
Requires:       kdeclarative-components >= %{_kf5_version}
Requires:       libKF5QuickAddons5 >= %{_kf5_version}
Requires:       libqt5-qtquickcontrols2
Suggests:       kdeconnect-kde

%description
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

%package -n %{lname}
Summary:        Framework to integrate services and actions - core library
Recommends:     %{name}

%description -n %{lname}
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the core library files of the package.

%package -n libKF5PurposeWidgets5
Summary:        Framework to integrate services and actions - GUI library
Recommends:     %{name}

%description -n libKF5PurposeWidgets5
This framework offers the possibility to create integrate services and actions
on any application without having to implement them specifically. Purpose will
offer them mechanisms to list the different alternatives to execute given the
requested action type and will facilitate components so that all the plugins
can receive all the information they need.

This package contains the library files of the package needed to use GUI widgets.

%package devel
Summary:        Framework to integrate services and actions - Build Environment
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       libKF5PurposeWidgets5 = %{version}
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}

%description devel
This package contains development files needed to build applications which rely on the purpose framework.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang libpurpose_quick %{name}.lang
%find_lang libpurpose_widgets %{name}.lang
%find_lang purpose-fileitemaction %{name}.lang
%find_lang purpose_barcode %{name}.lang
%find_lang purpose_bluetooth %{name}.lang
%find_lang purpose_imgur %{name}.lang
%find_lang purpose_kdeconnect %{name}.lang
%find_lang purpose_kdeconnectsms %{name}.lang
%find_lang purpose_ktp-sendfile %{name}.lang
%find_lang purpose_nextcloud %{name}.lang
%find_lang purpose_pastebin %{name}.lang
%find_lang purpose_phabricator %{name}.lang
%find_lang purpose_reviewboard %{name}.lang
%find_lang purpose_saveas %{name}.lang
%find_lang purpose_youtube %{name}.lang

%ldconfig_scriptlets -n %{lname}
%ldconfig_scriptlets -n libKF5PurposeWidgets5
%ldconfig_scriptlets

%files lang -f %{name}.lang

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Purpose.so.*
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories

%files -n libKF5PurposeWidgets5
%{_kf5_libdir}/libKF5PurposeWidgets.so.*

%files
%{_kf5_libdir}/libPhabricatorHelpers.so.*
%{_kf5_libdir}/libReviewboardHelpers.so.*
%{_kf5_libexecdir}/
%{_kf5_sharedir}/purpose/
%{_kf5_plugindir}/
%{_kf5_qmldir}/
%{_kf5_iconsdir}/hicolor/*/actions/kipiplugin_youtube.*
%{_kf5_iconsdir}/hicolor/*/apps/phabricator-purpose.*
%{_kf5_iconsdir}/hicolor/*/apps/reviewboard-purpose.*
%{_kf5_sharedir}/accounts/

%files devel
%{_kf5_libdir}/libKF5Purpose.so
%{_kf5_libdir}/libKF5PurposeWidgets.so
%{_kf5_libdir}/cmake/KDEExperimentalPurpose/
%{_kf5_includedir}/
%dir %{_kf5_cmakedir}/KF5Purpose
%{_kf5_cmakedir}/KF5Purpose/*.cmake

%changelog
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- Changes since 5.113.0:
  * Adapt to KAccounts API change
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Remove code variants for building with Qt 6
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Fix build with Qt 6.5
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Place Purpose::Menu headers into C++ namespace subdir, w/ compat headers
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * menudemo fix clazy-detaching-temporary
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Don't delete config when job finishes
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Add Qt6 windows CI support
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Fix QML warning, properly refer to the view
  * Remove unneeded EXPORT_SHARE_VERSION usages
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * kdeconnect: Fix name role
  * Add FreeBSD Qt 6 CI
  * Port the remaining QQC1 uses
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- No code change since 5.96.0
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * [plugins/email] Port to KEMailClientLauncherJob
  * Remove extra ';'
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * Use CommandLauncherJob to start kdeconnect-sms
  * port to away from Qt smart pointers where possible
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Port to ecm_add_qml_module
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * autotests: ensure org.kde.purpose is found in the builddir
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Remove call to ecm_find_qmlmodule(org.kde.kdeconnect)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Add Linux Qt6 CI
  * Compile with Qt6 as well
  * Install plugins in kf<version>
  * Add const'ref
  * Adapt build system for building against qt6
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * [imgur] Improve grammar of upload notification text
  * [imgur] Show deletion url in notification (kde#394181)
  * [imgur] Copy link to clipboard and show notification (kde#437347)
  * Don't build bluetooth plugin on non-Linux
  * Unbreak the Nextcloud plugin
  * Add Twitter URL plugin
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Port away from deprecated KPluginMetaData::readTranslatedString
  * Port away from deprecated KPluginLoader
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * cmake: Use custom command instead of custom target for copy
  * Set a title for JobDialog (kde#444205)
  * Improve job window buttons (kde#444145)
  * Fix whitespace punctuation in a warning
  * email: Ensure we don't crash when there's no mailto preferredService (kde#443788)
  * Make sharing via Telegram work again
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * plugins/barcode: Call it a "QR code" in the UI
  * Add Barcode plugin
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We depend against c++-17 so we can use qOverload directly
  * [imgur plugin] Add Delete Url support
  * replace "MacOSX" with "macOS"
  * Port Telegram plugin to KIO::ApplicationLauncherJob
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * [JobView] Show error when configuration fails to load
  * Clean up unneeded JSON parameter in kcoreaddons_add_plugin
  * Replace xdg-mime invokation with KApplicationTrader
  * Make sure empty list placeholder has some space around it
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Remove custom KPluginLoader de-duplication logic
  * [jobview] Remove unneeded intermediate item
  * Propagate implicitHeight properly
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
  * Fix cmake warning
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * FileItemActions: Use new signal to display errors
  * Port away from deprecated Qt methods
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- No code change since 5.80.0
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- No code change since 5.79.0
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * [nextcloud] Rework configuration UI
  * Evaluate initial configuration
  * Clip ListViews in kdeconnect and bluetooth config
  * Remove unneeded Layout attached properties
  * [plugins/nextcloud] Use Nextcloud icon
  * [cmake] Move find_package to toplevel CMakeLists.txt
* Sun Jan 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Avoid hard dependency of optional plugin requirements
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Remove not implemented method
  * autotests: fix ctest not exiting because of kio_http_cache_cleaner
  * KFileItemActions: add menu windowflag
  * Share fileitemplugin: use parent Widget as menu parent
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Remove unused include
  * [bluetooth] Fix sharing multiple files (kde#429620)
  * Read translated plugin action label (kde#429510)
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Add description to kaccounts youtube provider
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Port to ecm_generate_qmltypes
  * autotests: fix path separator on Windows
* Mon Sep 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Require accounts-qml-module
* Sat Sep 12 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with Qt 5.15.1:
  * 0001-Revert-Port-some-qt5.15-deprecated-method.patch
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * autotests: append to $QML2_IMPORT_PATH rather than replacing it
  * Apply initial configuration data when loading config UI
  * Restore behaviour of AlternativesView
  * [jobcontroller] Disable separate process
  * Rework job view handling (kde#419170)
  * Remove obsolete COPYING files
  * Remove obsolete KDevelop information
  * Add license texts according to REUSE specification
  * Convert license statements to SPDX expressions
- Drop a patch which will have been added in the future:
  * 0001-Revert-Port-some-qt5.15-deprecated-method.patch
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Explicitly use Kirigami units instead of implicitly using Plasma units
  * Port job dialogs to Kirigami.PlaceholderMessage
  * Fix mem leak. Configuration was never deleted
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Remove trailing ellipsis from "Imgur" menu item
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Rewrite nextcloud plugin
  * kill twitter support
  * Port deprecated method
  * Fix build with Qt 5.15.0
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * QJsonDocument::fromBinaryData is deprecated in qt5.15.
    We need to port to QCborValue::fromCbor
  * Port some qt5.15 deprecated method
  * Fix QRegularExpression::wildcardToRegularExpression() usage
  * [Purpose] Port QRegExp to QRegularExpression
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Use standard ECMQMLModules
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * include the cmake command we are about to use
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * autotests: simplify the code using job->exec().
  * i18n: Add ellipsis to action items (X-Purpose-ActionDisplay)
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes to list here.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Fix no device available text
  * autotests: fix disabling kio debug output
  * Fixed Telegram Desktop plugin on Fedora
  * Fix capitalization of Nextcloud
  * Add missing #include
  * Remove unused includes
  * Use new syntax
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Phabricator: open a new diff automatically in the browser
  * Use non-deprecated suggestName
  * Fix extraction. Patch by Victor Ryzhykh.
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Change initial size of the config dialog
  * Improve Job Dialog buttons' icons and text
  * Fix translation of actiondisplay
  * Add ellipsis where appropriate
  * Don't show error message if sharing is cancelled by the user
  * Fix warning when reading plugin metadata
  * Redesign config pages
  * Use QLatin1Char
  * Install in new logging directory when we use kf5 5.59.0
  * ECMPackageConfigHelpers -> CMakePackageConfigHelpers
  * phabricator: Fix fallthrough in switch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * [JobDialog] Also signal cancellation when window is closed by the user
  * Remove deprecated method qVariantFromValue->QVariant::fromValue
  * test: close the menudemo when the sharing process ends
  * Report cancelling a configuration as finished with an error (kde#407356)
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Ignore some qtcreator file
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Use https for the pastebin backend and publicly accessible documentation
  * Add KDE Connect SMS plugin
* Sat Apr  6 2019 wbauer@tmo.at
- Add knotifications-devel BuildRequires to build kfileitemaction
  plugin (boo#1131759)
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * pastebin: don't show progress notifications
  * sharetool: Show shared url on top
  * Fix sharing files with spaces or quotes in names via Telegram
  * Have ShareFileItemAction provide an output or an error if they are provided
  * Enable sharing URLs via email
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * remove obsolete comment
  * add missing properties
  * Add plugin type for sharing URLs
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * DiffListModel::refresh(): return at once when already active.
  * phabricator plugin: use Arcanist's diff.rev. order (kde#401565)
  * Remove unneeded import
  * Provide a title for JobDialog
  * Allow the JobDialog to get a nicer initial size (kde#400873)
  * Make it possible for the menudemo to share different urls
  * Port what we can to QQC2
  * Use QQC2 for the JobDialog (kde#400996, kde#400997)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Reuse resultMap instead of converting to map two times more
  * Remove unused variable
  * Set Dialog flag for JobDialog
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Add explicit
  * Make cmake 3.0 the minimum cmake version
  * phabricator: Fix warning
  * Make compile with strict compile flags
  * Port to debug categories
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * autotests: use QTemporaryDir instead of a hardcoded filename
  * autotests: remove dependency on klauncher, in the hope to fix Windows CI
  * autotests: actually disable copyjob debug output in CI
  * Use a temp dir so that an existing /tmp/purposetest file doesn't break the test.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Make sure debugging for kf5.kio.core.copyjob is disabled for the test
  * Don't clean up the configuration too early
  * Add bluetooth plugin
  * [Telegram] Don't wait for Telegram to be closed
  * Prepare to use Arc's status colours in the revision drop-down list
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Add Share action to Dolphin context menu
  * Properly reset plugins
  * Filter out duplicate plugins
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Extend X-Purpose-Constraints documentation
  * Improve Telegram integration
  * Treat inner arrays as OR constraints rather than AND
  * Make it possible to constrain plugins by a desktop file presence
  * Make it possible to filter plugins by executable
  * Fix i18n
  * Fix i18n issues in Phabricator Plugin
  * Highlight the selected device in the KDE Connect plugin
  * Fix Phabricator icon
  * fix i18n issues in framworks/purpose/plugins
  * Use override
  * Add Telegram plugin
  * kdeconnect: Notify when the process fails to start
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Readability
  * Make sure we give some vertical space to configuration plugins
  * Port KDEConnect plugin config to QQC2
  * Port AlternativesView to QQC2
  * Warning--
- Adjust runtime requirements
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * We use qt5.8.0 now
  * Use qt5.8.0 as all framework
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * forgot to commit it
  * Generate debug categories and create file for it
  * Fix tier, accommodate for KIO
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * Now part of KDE Frameworks 5
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 1.2.1:
  * Too many changes to list here
* Fri Oct 27 2017 wbauer@tmo.at
- Update to 1.2.1
  * Add back the translations that were missing completely in 1.2
* Mon Oct 23 2017 wbauer@tmo.at
- Update to 1.2
  * New plugins: nextcloud, email, phabricator
  * Possibility to disable plugins via config file
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 1.1
  * No changelog provided
* Sat Oct  3 2015 hrvoje.senjan@gmail.com
- Update to 1.0
  * No changelog provided
- Drop build.patch, upstreamed
* Tue Aug 18 2015 hrvoje.senjan@gmail.com
- Install license
* Mon Aug 17 2015 hrvoje.senjan@gmail.com
- Don't ship reviewboard icon, it's delivered with kdevplatform
* Sun Aug  9 2015 hrvoje.senjan@gmail.com
- Activate purpose package
